# Buble
  
-- includes  
en: import library OS  
ru: импортируем библиотеку OS  
  
-- #en: perimeter ru: периметр      

en: [см. __init__.py]  
ru:  

	функция периметр(принимает длину, ширину - которая поумолчанию равна пустота)  

		если ширина не равна пустота то  

			обработать ошибки  

				вернуть периметр прямоугольника  

			есть ошибки  

				вернуть ошибка!  

		иначе  

			обработать ошибки  

				вернуть периметр квадрата  

			есть ошибки  

				вернуть ошибка!  
  
-- en: square ru: площадь  
en: [см. __init__.py]  
ru:  

	функция площадь(принимает длину, ширину - которая поумолчанию равна пустота)  
 
		если ширина не равна пустота то  
  
			обработать ошибки  
   
				вернуть площадь прямоугольника  
    
			есть ошибки  
   
				вернуть ошибка!  
    
		иначе  
  
			обработать ошибки  
   
				вернуть площадь квадрата  
    
			есть ошибки  
   
				вернуть ошибка!  
    
  
 ## другое
 ## другое  
 ## другое 
  
-- en: if else elif ru: если | иначе | иначе если  
en: --  
ru:  

	функция еслииначе(принимает условие, действие, [другое см. переводчик])  
 
		обработать ошибки  
  
			если [eval и str - см конец readme.md] переменная условие  
   
				вернуть действие  
    
			иначе если переменная условие  
   
				вернуть действие  
    
			иначе  
   
				вернуть действие  
    
		есть ошибки  
  
			вернуть ошибка! [ост. - см. переводчик] 
   
			  
-- en: for ru: пока  
en: [см. __init__.py]  
ru:  

	функция форв(принимает условие, действие)
 
		обработать ошибки  
  
			пока условие  
   
				вернуть действие  
    
		есть ошибки  
  
			вернуть ошибка! [ост. - см. переводчик]  
   
			
-- en: for ru: пока  
en: [см. __init__.py]  
ru:  

	функция дляв(принимает условие, действие, диапазон)  
 
		обработать ошибки  
  
			комментарий: возращает пока [см. ошибки при создании библиотеки]  
   
			для условие в диапазон  
   
				вернуть действие  
    
		есть ошибки  
  
			вернуть ошибка! [ост. - см. переводчик]  
   
-- en: classic function ru: функции обычного типа   
en: [см. __init__.py]  
ru:  

	функции обычного типа не объясняються!

####End::

--------------------------------------------------------  

----------   все см. будут добавлены позже!   ----------
